@@ -38,8 +38,6 @@ cfg_status_report!(
 pub(crate) type SharedMotivation = Arc<AtomicBool>;
 // Global IdGenerator.
 pub(crate) type SharedIdGenerator = Arc<AsyncMutex<SnowflakeIdGenerator>>;
-// Global sencond hand.
-pub(crate) type SencondHand = Arc<AtomicU64>;
 // Global Timestamp.
 pub(crate) type GlobalTime = Arc<AtomicU64>;
 // Shared task-wheel for operate.
@@ -47,6 +45,25 @@ pub(crate) type SharedTaskWheel = Arc<DashMap<u64, Slot>>;
 // The slot currently used for storing global tasks.
 pub(crate) type SharedTaskFlagMap = Arc<DashMap<u64, TaskMark>>;
 
+/// Global sencond hand.
+#[derive(Debug, Clone, Default)]
+pub(crate) struct SencondHand {
+    pub(crate) inner: Arc<AtomicU64>,
+}
+
+impl SencondHand {
+    pub(crate) fn current_second_hand(&self) -> u64 {
+        self.inner.load(Ordering::Acquire)
+    }
+
+    pub(crate) fn next(&self) -> Result<u64, u64> {
+        self.inner
+            .fetch_update(Ordering::Release, Ordering::Relaxed, |x| {
+                Some((x + 1) % DEFAULT_TIMER_SLOT_COUNT)
+            })
+    }
+}
+
 /// Builds DelayTimer with custom configuration values.
 ///
 /// Methods can be chained in order to set the configuration values. The
@@ -176,8 +193,8 @@ impl Default for SharedHeader {
     fn default() -> Self {
         let wheel_queue = EventHandle::init_task_wheel(DEFAULT_TIMER_SLOT_COUNT);
         let task_flag_map = Arc::new(DashMap::new());
-        let second_hand = Arc::new(AtomicU64::new(0));
-        let global_time = Arc::new(AtomicU64::new(get_timestamp()));
+        let second_hand = SencondHand::default();
+        let global_time = Arc::new(AtomicU64::new(timestamp()));
         let shared_motivation = Arc::new(AtomicBool::new(true));
         let runtime_instance = RuntimeInstance::default();
         let id_generator = Arc::new(AsyncMutex::new(SnowflakeIdGenerator::new(1, 1)));
@@ -224,18 +241,18 @@ impl DelayTimerBuilder {
             .build()
             .ok_or_else(|| anyhow!("Missing base component, can't initialize."))?;
 
-        let timer = Timer::new(self.get_timer_event_sender(), shared_header.clone());
-
         match self.runtime_instance.kind {
-            RuntimeKind::Smol => self.assign_task(timer, event_handle),
+            RuntimeKind::Smol => self.assign_task(event_handle, shared_header),
 
-            RuntimeKind::Tokio => self.assign_task_by_tokio(timer, event_handle, shared_header),
+            RuntimeKind::Tokio => self.assign_task_by_tokio(event_handle, shared_header),
         };
 
         Ok(())
     }
 
-    fn assign_task(&self, timer: Timer, event_handle: EventHandle) {
+    fn assign_task(&mut self, event_handle: EventHandle, shared_header: SharedHeader) {
+        let timer = Timer::new(self.get_timer_event_sender(), shared_header);
+
         self.run_async_schedule(timer);
 
         self.run_event_handle(event_handle);
@@ -383,23 +400,22 @@ impl DelayTimer {
 /// This function requires the `tokio-support` feature of the `delay_timer`
 /// crate to be enabled.
 impl DelayTimerBuilder {
-    fn assign_task_by_tokio(
-        &mut self,
-        timer: Timer,
-        event_handle: EventHandle,
-        shared_header: SharedHeader,
-    ) {
-        self.run_async_schedule_by_tokio(timer, shared_header.clone());
+    fn assign_task_by_tokio(&mut self, event_handle: EventHandle, shared_header: SharedHeader) {
+        self.run_async_schedule_by_tokio(shared_header.clone());
         self.run_event_handle_by_tokio(event_handle, shared_header);
     }
 
-    fn run_async_schedule_by_tokio(&self, mut timer: Timer, shared_header: SharedHeader) {
+    fn run_async_schedule_by_tokio(&mut self, shared_header: SharedHeader) {
+        let shared_header_by_timer = shared_header.clone();
+        let timer_event_sender = self.get_timer_event_sender();
+
         if let Some(ref tokio_runtime_ref) = shared_header.runtime_instance.inner {
             let tokio_runtime = tokio_runtime_ref.clone();
             Builder::new()
                 .name("async_schedule_tokio".into())
                 .spawn(move || {
                     tokio_runtime.block_on(async {
+                        let mut timer = Timer::new(timer_event_sender, shared_header_by_timer);
                         timer.async_schedule().await;
                     })
                 })
@@ -510,7 +526,7 @@ cfg_status_report!(
 // to get rid of system interference,
 // and this change can also be applied to snowflake-rs.
 /// get current OS SystemTime.
-pub fn get_timestamp() -> u64 {
+pub fn timestamp() -> u64 {
     match SystemTime::now().duration_since(SystemTime::UNIX_EPOCH) {
         Ok(n) => n.as_secs(),
         Err(_) => panic!("SystemTime before UNIX EPOCH!"),
@@ -522,7 +538,7 @@ pub fn get_timestamp() -> u64 {
 // to get rid of system interference,
 // and this change can also be applied to snowflake-rs.
 /// get current OS SystemTime.
-pub fn get_timestamp_micros() -> u128 {
+pub fn timestamp_micros() -> u128 {
     match SystemTime::now().duration_since(SystemTime::UNIX_EPOCH) {
         Ok(n) => n.as_micros(),
         Err(_) => panic!("SystemTime before UNIX EPOCH!"),
