@@ -10,7 +10,7 @@
 //!
 //! The prelude may grow over time as additional items see ubiquitous use.
 
-pub use crate::entity::{get_timestamp, get_timestamp_micros, DelayTimer, DelayTimerBuilder};
+pub use crate::entity::{timestamp, timestamp_micros, DelayTimer, DelayTimerBuilder};
 pub use crate::error::*;
 pub use crate::timer::runtime_trace::state::instance;
 pub use crate::timer::runtime_trace::task_handle::DelayTaskHandler;
@@ -54,7 +54,7 @@ pub(crate) use log::{debug, error, info, trace};
 pub(crate) use smol::channel::{unbounded, Receiver as AsyncReceiver, Sender as AsyncSender};
 pub(crate) use smol::future::yield_now;
 pub(crate) use smol::lock::Mutex as AsyncMutex;
-pub(crate) use smol::Timer;
+pub(crate) use smol::Timer as AsyncTimer;
 pub(crate) use std::convert::{TryFrom, TryInto};
 pub(crate) use std::future::Future;
 pub(crate) use std::iter::StepBy;
